@@ -53,7 +53,7 @@ class Circle(sge.StellarClass):
 
     def event_mouse_move(self, x, y):
         if self.collides(sge.game.mouse):
-            self.image_blend = "#ff0000"
+            self.image_blend = "red"
         else:
             self.image_blend = (0, 0, 255)
 
