@@ -15,6 +15,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 
 import pygame
@@ -138,7 +143,7 @@ class Music(object):
             if self._full_fname is None:
                 print("Directories searched:")
                 for d in sge.music_directories:
-                    print((os.path.normpath(os.path.abspath(d))))
+                    print(os.path.normpath(os.path.abspath(d)))
                 msg = 'File "{0}" not found.'.format(self.fname)
                 raise IOError(msg)
 
@@ -162,7 +167,7 @@ class Music(object):
 
         sge.game.music[self.id] = self
 
-    def play(self, start=0, loops=0, maxtime=None, fade_time=None):
+    def play(self, start=0, loops=1, maxtime=None, fade_time=None):
         """Play the music.
 
         Arguments:
@@ -178,7 +183,7 @@ class Music(object):
             if not self.playing:
                 pygame.mixer.music.load(self._full_fname)
 
-            if loops is None:
+            if not loops:
                 loops = -1
 
             sge.game._music = self
@@ -201,7 +206,7 @@ class Music(object):
                 except NotImplementedError:
                     pygame.mixer.music.play(loops)
 
-    def queue(self, start=0, loops=0, maxtime=None, fade_time=None):
+    def queue(self, start=0, loops=1, maxtime=None, fade_time=None):
         """Queue the music for playback.
 
         This will cause the music to be added to a list of music to play
